==> tuia-advert-center-api-2.2.72-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/AdvertiserApiToolDto.java <==
package cn.com.duiba.tuia.core.api.dto.advertiser;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author zhangmeng
 * @date 2019/8/1
 * @function
 */
public class AdvertiserApiToolDto implements Serializable {


    private static final long serialVersionUID = 1506637487870608820L;

    private Long id;

    /**
     * 广告主传递的advertKey
     */
    private String advertKey;

    /**
     * 设备id idfa/imei
     */
    private String deviceId;

    /**
     * 用户传递的id
     */
    private String ip;

    /**
     * 用户传递的ua
     */
    private String ua;

    /**
     * 回传类型
     * @AdvertSubtypeEnum
     */
    private String subType;

    /**
     * 失败，成功
     */
    private String status;

    /**
     * 失败，成功
     */
    private String a_oId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getAdvertKey() {
        return advertKey;
    }

    public void setAdvertKey(String advertKey) {
        this.advertKey = advertKey;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

    public String getA_oId() {
        return a_oId;
    }

    public void setA_oId(String a_oId) {
        this.a_oId = a_oId;
    }
}

==> tuia-advert-center-api-2.6.17-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/AdvertiserApiToolDto.java <==
package cn.com.duiba.tuia.core.api.dto.advertiser;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author zhangmeng
 * @date 2019/8/1
 * @function
 */
public class AdvertiserApiToolDto implements Serializable {


    private static final long serialVersionUID = 1506637487870608820L;

    private Long id;

    /**
     * 广告主传递的advertKey
     */
    private String advertKey;

    /**
     * 设备id idfa/imei
     */
    private String deviceId;

    /**
     * 用户传递的id
     */
    private String ip;

    /**
     * 用户传递的ua
     */
    private String ua;

    /**
     * 回传类型
     * @AdvertSubtypeEnum
     */
    private String subType;

    /**
     * 失败，成功
     */
    private String status;

    /**
     * 失败，成功
     */
    private String a_oId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 扩展信息
     */
    private String ex;

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getEx() {
        return ex;
    }

    public void setEx(String ex) {
        this.ex = ex;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getAdvertKey() {
        return advertKey;
    }

    public void setAdvertKey(String advertKey) {
        this.advertKey = advertKey;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

    public String getA_oId() {
        return a_oId;
    }

    public void setA_oId(String a_oId) {
        this.a_oId = a_oId;
    }
}
